@@ -13,14 +13,7 @@ def test_create_list_delete_console(api):
     assert not delete_console.error
 
 
-def test_list_consoles(api):
-    consoles = api.list_consoles()
-
-    assert not consoles.error
-    assert len(consoles.data) > 0
-
-
-def test_console_input_output(api, web, constants):
+def test_console_input_output(api, web):
     string = uuid.uuid4().hex
 
     create_console = api.create_console()
@@ -85,3 +78,9 @@ def test_get_tasks(api, constants):
     assert tasks.data[0]['command'] == task.data['command']
     assert tasks.data[0]['hour'] == task.data['hour']
     assert tasks.data[0]['minute'] == task.data['minute']
+
+
+def test_reload_app(api, constants):
+    reload = api.reload_app(constants['PA_APP_NAME'])
+
+    assert not reload.error
